@@ -2,7 +2,7 @@ from pandas.api.types import is_numeric_dtype
 from grplot.features.sep.text_sep.text_sep_def import text_sep_def
 
 
-def text_sep_data_def(num, df, axislabel, sep):
+def text_sep_data_def(df, num, axislabel, sep):
     if axislabel in df:
         if is_numeric_dtype(type(num)) == True: 
             num = text_sep_def(num=num, sep=sep)
